==> SQLiteCSLib_Src_1_4.zip: SQLiteCSLib_Src_1_4/1.x/TestAppCE/TestForm.cs <==
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

using SQLiteCSLib;
using SQLiteCSLib.Inner;

namespace TestAppCE
{
	/// <summary>
	/// TestForm ̊Tv̐łB
	/// </summary>
	public class TestForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button button1;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Button button3;
		private System.Windows.Forms.Button button4;
		private System.Windows.Forms.Button button5;
		private System.Windows.Forms.Button button2;
	
		/// <summary>
		/// RXgN^
		/// </summary>
		public TestForm()
		{
			InitializeComponent();
		}

		/// <summary>
		/// gpĂ郊\[XɌ㏈s܂B
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			base.Dispose( disposing );
		}

		#region Windows tH[ fUCiŐꂽR[h 
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
			this.button1 = new System.Windows.Forms.Button();
			this.button2 = new System.Windows.Forms.Button();
			this.label1 = new System.Windows.Forms.Label();
			this.button3 = new System.Windows.Forms.Button();
			this.button4 = new System.Windows.Forms.Button();
			this.button5 = new System.Windows.Forms.Button();
			// 
			// button1
			// 
			this.button1.Location = new System.Drawing.Point(24, 16);
			this.button1.Text = "I";
			this.button1.Click += new System.EventHandler(this.button1_Click);
			// 
			// button2
			// 
			this.button2.Location = new System.Drawing.Point(24, 56);
			this.button2.Text = "1";
			this.button2.Click += new System.EventHandler(this.button2_Click);
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(136, 16);
			this.label1.Size = new System.Drawing.Size(200, 20);
			this.label1.Text = "label1";
			// 
			// button3
			// 
			this.button3.Location = new System.Drawing.Point(24, 96);
			this.button3.Text = "2";
			this.button3.Click += new System.EventHandler(this.button3_Click);
			// 
			// button4
			// 
			this.button4.Location = new System.Drawing.Point(24, 136);
			this.button4.Text = "3";
			this.button4.Click += new System.EventHandler(this.button4_Click);
			// 
			// button5
			// 
			this.button5.Location = new System.Drawing.Point(24, 176);
			this.button5.Text = "4";
			this.button5.Click += new System.EventHandler(this.button5_Click);
			// 
			// TestForm
			// 
			this.Controls.Add(this.button3);
			this.Controls.Add(this.label1);
			this.Controls.Add(this.button2);
			this.Controls.Add(this.button1);
			this.Controls.Add(this.button4);
			this.Controls.Add(this.button5);
			this.Text = "TestForm";

		}
		#endregion

		/// <summary>
		/// I{^
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button1_Click(object sender, System.EventArgs e)
		{
			this.Close();
		}

		/// <summary>
		/// 1{^
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button2_Click(object sender, System.EventArgs e)
		{
			label1.Text = "1";

			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					label1.Text = "Before OPEN";

					db.Open();

					label1.Text = "DB OPEN";

					IDbCommand cmd = db.CreateCommand();
					object res = null;
					try
					{
						cmd.CommandText = "DROP TABLE tb5 ";
						res = cmd.ExecuteScalar();
					}
					catch
					{
					}

					cmd = db.CreateCommand();
					cmd.CommandText = "CREATE TABLE tb5 ( pid INTEGER PRIMARY KEY, bin blob, cul3 text, cul4 real, cul5 INTEGER, cul6 real )";
					res = cmd.ExecuteScalar();

					label1.Text = "CREATE TABLE";

					IDbTransaction tran = db.BeginTransaction();

					for( int iIdx=0; iIdx<1000; iIdx++ )
					{
						cmd.Parameters.Clear();

						SQLiteParameter idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":id";
						idp.Value = iIdx;
						idp.Order = 0;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":bin";
						idp.Value = new byte[]{0x01, 0x02, 0x03};
						idp.Order = 1;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":tt1";
						idp.Value = string.Format("Ă{0}",iIdx);
						idp.Order = 2;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":tt2";
						double dVal = ((double)iIdx) + 2.5;
						idp.Value = dVal;
						idp.Order = 3;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":tt2";
						long lVal = iIdx + 50000000;
						idp.Value = lVal;
						idp.Order = 4;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":tt3";
						decimal deVal = ((decimal)iIdx) + 66.99m;
						idp.Value = deVal;
						idp.Order = 5;
						cmd.Parameters.Add( idp );

						cmd.CommandText = "INSERT INTO tb5( pid, bin, cul3, cul4, cul5, cul6 ) values( ?, ?, ?, ?, ?, ? )";
						cmd.ExecuteNonQuery();
					}

					label1.Text = "INSERT";


					tran.Commit();

					label1.Text = "Commit";

				}
			}
			catch( Exception ex )
			{
				string mes = ex.Message;

				MessageBox.Show( mes );
			}		
		}

		/// <summary>
		/// 2{^
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button3_Click(object sender, System.EventArgs e)
		{
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					label1.Text = "BEFORE";

					db.Open();

					label1.Text = "OPEN";

					IDbCommand cmd = db.CreateCommand();

					label1.Text = "CreateCommand";

					cmd.CommandText = "SELECT * FROM tb5 ";
					using( IDataReader reader = cmd.ExecuteReader() )
					{
						label1.Text = "READ";

						while( reader.Read() == true )
						{
							label1.Text = "RECORD";

							int iCnt = reader.FieldCount;

							string sCName = reader.GetName( 0 );

							object c1 = reader.GetValue( 0 );
							label1.Text = "C1";

							object c2 = reader.GetValue( 1 );
							label1.Text = "C2";

							object c3 = reader.GetValue( 2 );
							label1.Text = "C3";

							object c4 = reader.GetValue( 3 );
							label1.Text = "C4";

							object c5 = reader.GetValue( 4 );
							label1.Text = "C5";

							object c6 = reader.GetValue( 5 );
							label1.Text = "C5";

						}
					}

					label1.Text = " ";
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;

				MessageBox.Show( mes );
			}		
		}

		#region [U`ƍ
		/// <summary>
		/// XJ[p
		/// </summary>
		protected class CollationEx : SQLiteCSLib.Inner.ICollationFunction
		{
			/// <summary>
			/// r
			/// </summary>
			/// <param name="key1">rL[1</param>
			/// <param name="key2">rL[2</param>
			/// <returns> -1,0,1</returns>
			public int Compare( string key1, string key2 )
			{
				if( key1 == "" )
					return 1;

				if( key2 == "" )
					return -1;

				return key1.CompareTo( key2 );
			}
		};

		#endregion

		/// <summary>
		/// 3{^
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button4_Click(object sender, System.EventArgs e)
		{

			label1.Text = "";
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					IDbCommand cmdx = db.CreateCommand();
					object res = null;

					try
					{
						cmdx.CommandText = "CREATE TABLE tb2 ( pid INTEGER PRIMARY KEY, name TEXT )";
						res = cmdx.ExecuteScalar();
					}
					catch
					{}

					cmdx = db.CreateCommand();
					cmdx.CommandText = "DELETE FROM tb2";
					cmdx.ExecuteScalar();

					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 1, 'AET' )";
					cmdx.ExecuteScalar();
					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 2, '' )";
					cmdx.ExecuteScalar();
					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 3, '0' )";
					cmdx.ExecuteScalar();


					//[U`֐
					CollationEx collationex = new CollationEx(); 

					//[U`֐o^
					SQLiteCSLib.Inner.ResultEnum rest = db.CreateCollation("D" , collationex);

					IDbCommand cmd = db.CreateCommand();
					cmd.CommandText = "SELECT pid, name FROM tb2 order by name collate D";

					using( IDataReader reader = cmd.ExecuteReader() )
					{
						while( reader.Read() == true )
						{
							object c1 = reader.GetValue( 0 );
							object c2 = reader.GetValue( 1 );

							label1.Text = string.Format(" {0},{1}",c1,c2 );
						}
					}
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
				label1.Text = mes;
			}		
		}

		#region [U`֐eXg

		/// <summary>
		/// XJ[p
		/// </summary>
		protected class ScalarFunc : SQLiteCSLib.Inner.IScalarCallUserFunction
		{
			/// <summary>
			/// ֐R[obN
			/// </summary>
			/// <param name="args"></param>
			public object CallFunc( object[] args )
			{
				foreach( object arg in args )
				{
					if( arg != null )
						Console.Write( arg.ToString() );
				}

				return 1;
			}
		};

		/// <summary>
		/// Wp
		/// </summary>
		protected class AggregateFunc : SQLiteCSLib.Inner.IAggregateCallUserFunction
		{
			/// <summary>
			/// ֐R[obN
			/// </summary>
			/// <param name="args"></param>
			public void CallStep( object[] args )
			{
				foreach( object arg in args )
				{
					if( arg != null )
						Console.Write( arg.ToString() );
				}
			}

			/// <summary>
			/// ֐R[obN
			/// </summary>
			public object CallFinal()
			{
				double dVal = 2.3;

				return dVal;
			}
		};
		#endregion

		/// <summary>
		/// 4{^
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button5_Click(object sender, System.EventArgs e)
		{
			label1.Text = "";
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					//[U`֐
					ScalarFunc scalarfunc = new ScalarFunc(); 
					AggregateFunc aggregatefunc = new AggregateFunc();

					//[U`֐o^
					SQLiteCSLib.Inner.ResultEnum rest = db.CreateFunction("SCALAR1", 2, scalarfunc);
					rest = db.CreateFunction("AGGREGATE1", 2, aggregatefunc);

					IDbCommand cmd = db.CreateCommand();
					cmd.CommandText = "SELECT SCALAR1( pid, name ),AGGREGATE1( 'Ă', 2.5 )  FROM tb2 ";

					using( IDataReader reader = cmd.ExecuteReader() )
					{
						while( reader.Read() == true )
						{
							object c1 = reader.GetValue( 0 );
							object c2 = reader.GetValue( 1 );

							label1.Text = string.Format(" {0},{1}",c1,c2 );
						}
					}
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
				label1.Text = mes;
			}
		}
	}
}

==> SQLiteCSLib_Src_1_5.zip: SQLiteCSLib_Src_1_5/1.x/TestAppCE/TestForm.cs <==
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

using SQLiteCSLib;
using SQLiteCSLib.Inner;

namespace TestAppCE
{
	/// <summary>
	/// TestForm ̊Tv̐łB
	/// </summary>
	public class TestForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button button1;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Button button3;
		private System.Windows.Forms.Button button4;
		private System.Windows.Forms.Button button5;
		private System.Windows.Forms.Button button2;
	
		/// <summary>
		/// RXgN^
		/// </summary>
		public TestForm()
		{
			InitializeComponent();
		}

		/// <summary>
		/// gpĂ郊\[XɌ㏈s܂B
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			base.Dispose( disposing );
		}

		#region Windows tH[ fUCiŐꂽR[h 
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
			this.button1 = new System.Windows.Forms.Button();
			this.button2 = new System.Windows.Forms.Button();
			this.label1 = new System.Windows.Forms.Label();
			this.button3 = new System.Windows.Forms.Button();
			this.button4 = new System.Windows.Forms.Button();
			this.button5 = new System.Windows.Forms.Button();
			// 
			// button1
			// 
			this.button1.Location = new System.Drawing.Point(24, 16);
			this.button1.Text = "I";
			this.button1.Click += new System.EventHandler(this.button1_Click);
			// 
			// button2
			// 
			this.button2.Location = new System.Drawing.Point(24, 56);
			this.button2.Text = "1";
			this.button2.Click += new System.EventHandler(this.button2_Click);
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(136, 16);
			this.label1.Size = new System.Drawing.Size(200, 20);
			this.label1.Text = "label1";
			// 
			// button3
			// 
			this.button3.Location = new System.Drawing.Point(24, 96);
			this.button3.Text = "2";
			this.button3.Click += new System.EventHandler(this.button3_Click);
			// 
			// button4
			// 
			this.button4.Location = new System.Drawing.Point(24, 136);
			this.button4.Text = "3";
			this.button4.Click += new System.EventHandler(this.button4_Click);
			// 
			// button5
			// 
			this.button5.Location = new System.Drawing.Point(24, 176);
			this.button5.Text = "4";
			this.button5.Click += new System.EventHandler(this.button5_Click);
			// 
			// TestForm
			// 
			this.Controls.Add(this.button3);
			this.Controls.Add(this.label1);
			this.Controls.Add(this.button2);
			this.Controls.Add(this.button1);
			this.Controls.Add(this.button4);
			this.Controls.Add(this.button5);
			this.Text = "TestForm";

		}
		#endregion

		/// <summary>
		/// I{^
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button1_Click(object sender, System.EventArgs e)
		{
			this.Close();
		}

		/// <summary>
		/// 1{^
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button2_Click(object sender, System.EventArgs e)
		{
			label1.Text = "1";

			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					label1.Text = "Before OPEN";

					db.Open();

					string dbversion = db.Database;

					label1.Text = "DB OPEN";

					IDbCommand cmd = db.CreateCommand();
					object res = null;
					try
					{
						cmd.CommandText = "DROP TABLE tb5 ";
						res = cmd.ExecuteScalar();
					}
					catch
					{
					}

					cmd = db.CreateCommand();
					cmd.CommandText = "CREATE TABLE tb5 ( pid INTEGER PRIMARY KEY, bin blob, cul3 text, cul4 real, cul5 INTEGER, cul6 real )";
					res = cmd.ExecuteScalar();

					label1.Text = "CREATE TABLE";

					IDbTransaction tran = db.BeginTransaction();

					for( int iIdx=0; iIdx<1000; iIdx++ )
					{
						cmd.Parameters.Clear();

						SQLiteParameter idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":id";
						idp.Value = iIdx;
						idp.Order = 0;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":bin";
						idp.Value = new byte[]{0x01, 0x02, 0x03};
						idp.Order = 1;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":tt1";
						idp.Value = string.Format("Ă{0}",iIdx);
						idp.Order = 2;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":tt2";
						double dVal = ((double)iIdx) + 2.5;
						idp.Value = dVal;
						idp.Order = 3;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":tt2";
						long lVal = iIdx + 50000000;
						idp.Value = lVal;
						idp.Order = 4;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":tt3";
						decimal deVal = ((decimal)iIdx) + 66.99m;
						idp.Value = deVal;
						idp.Order = 5;
						cmd.Parameters.Add( idp );

						cmd.CommandText = "INSERT INTO tb5( pid, bin, cul3, cul4, cul5, cul6 ) values( ?, ?, ?, ?, ?, ? )";
						cmd.ExecuteNonQuery();
					}

					label1.Text = "INSERT";


					tran.Commit();

					label1.Text = "Commit";

				}
			}
			catch( Exception ex )
			{
				string mes = ex.Message;

				MessageBox.Show( mes );
			}		
		}

		/// <summary>
		/// 2{^
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button3_Click(object sender, System.EventArgs e)
		{
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					label1.Text = "BEFORE";

					db.Open();

					label1.Text = "OPEN";

					IDbCommand cmd = db.CreateCommand();

					label1.Text = "CreateCommand";

					cmd.CommandText = "SELECT * FROM tb5 ";
					using( SQLiteDataReader reader = cmd.ExecuteReader() as SQLiteDataReader )
					{
						label1.Text = "READ";

						while( reader.Read() == true )
						{
							label1.Text = "RECORD";

							int iCnt = reader.FieldCount;

							string sCName = reader.GetName( 0 );

							object c1 = reader.GetValue( 0 );
							label1.Text = "C1";

							object c2 = reader.GetValue( 1 );
							label1.Text = "C2";

							object c3 = reader.GetValue( 2 );
							label1.Text = "C3";

							object c4 = reader.GetValue( 3 );
							label1.Text = "C4";

							object c5 = reader.GetValue( 4 );
							label1.Text = "C5";

							object c6 = reader.GetValue( 5 );
							label1.Text = "C5";

							string a1 = reader.GetColumnOriginalName( 0 );
							string a2 = reader.GetColumnDecltype( 0 );

						}
					}

					label1.Text = " ";
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;

				MessageBox.Show( mes );
			}		
		}

		#region [U`ƍ
		/// <summary>
		/// XJ[p
		/// </summary>
		protected class CollationEx : SQLiteCSLib.Inner.ICollationFunction
		{
			/// <summary>
			/// r
			/// </summary>
			/// <param name="key1">rL[1</param>
			/// <param name="key2">rL[2</param>
			/// <returns> -1,0,1</returns>
			public int Compare( string key1, string key2 )
			{
				if( key1 == "" )
					return 1;

				if( key2 == "" )
					return -1;

				return key1.CompareTo( key2 );
			}
		};

		#endregion

		/// <summary>
		/// 3{^
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button4_Click(object sender, System.EventArgs e)
		{

			label1.Text = "";
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					IDbCommand cmdx = db.CreateCommand();
					object res = null;

					try
					{
						cmdx.CommandText = "CREATE TABLE tb2 ( pid INTEGER PRIMARY KEY, name TEXT )";
						res = cmdx.ExecuteScalar();
					}
					catch
					{}

					cmdx = db.CreateCommand();
					cmdx.CommandText = "DELETE FROM tb2";
					cmdx.ExecuteScalar();

					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 1, 'AET' )";
					cmdx.ExecuteScalar();
					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 2, '' )";
					cmdx.ExecuteScalar();
					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 3, '0' )";
					cmdx.ExecuteScalar();

					long lRowid = db.getLastInsertROWID();

					//[U`֐
					CollationEx collationex = new CollationEx(); 

					//[U`֐o^
					SQLiteCSLib.Inner.ResultEnum rest = db.CreateCollation("D" , collationex);

					IDbCommand cmd = db.CreateCommand();
					cmd.CommandText = "SELECT pid, name FROM tb2 order by name collate D";

					using( IDataReader reader = cmd.ExecuteReader() )
					{
						while( reader.Read() == true )
						{
							object c1 = reader.GetValue( 0 );
							object c2 = reader.GetValue( 1 );

							label1.Text = string.Format(" {0},{1}",c1,c2 );
						}
					}
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
				label1.Text = mes;
			}		
		}

		#region [U`֐eXg

		/// <summary>
		/// XJ[p
		/// </summary>
		protected class ScalarFunc : SQLiteCSLib.Inner.IScalarCallUserFunction
		{
			/// <summary>
			/// ֐R[obN
			/// </summary>
			/// <param name="args"></param>
			public object CallFunc( object[] args )
			{
				foreach( object arg in args )
				{
					if( arg != null )
						Console.Write( arg.ToString() );
				}

				return 1;
			}
		};

		/// <summary>
		/// Wp
		/// </summary>
		protected class AggregateFunc : SQLiteCSLib.Inner.IAggregateCallUserFunction
		{
			/// <summary>
			/// ֐R[obN
			/// </summary>
			/// <param name="args"></param>
			public void CallStep( object[] args )
			{
				foreach( object arg in args )
				{
					if( arg != null )
						Console.Write( arg.ToString() );
				}
			}

			/// <summary>
			/// ֐R[obN
			/// </summary>
			public object CallFinal()
			{
				double dVal = 2.3;

				return dVal;
			}
		};
		#endregion

		/// <summary>
		/// 4{^
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button5_Click(object sender, System.EventArgs e)
		{
			label1.Text = "";
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					//[U`֐
					ScalarFunc scalarfunc = new ScalarFunc(); 
					AggregateFunc aggregatefunc = new AggregateFunc();

					//[U`֐o^
					SQLiteCSLib.Inner.ResultEnum rest = db.CreateFunction("SCALAR1", 2, scalarfunc);
					rest = db.CreateFunction("AGGREGATE1", 2, aggregatefunc);

					IDbCommand cmd = db.CreateCommand();
					cmd.CommandText = "SELECT SCALAR1( pid, name ),AGGREGATE1( 'Ă', 2.5 )  FROM tb2 ";

					using( IDataReader reader = cmd.ExecuteReader() )
					{
						while( reader.Read() == true )
						{
							object c1 = reader.GetValue( 0 );
							object c2 = reader.GetValue( 1 );

							label1.Text = string.Format(" {0},{1}",c1,c2 );
						}
					}
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
				label1.Text = mes;
			}
		}
	}
}
